@@ -1032,7 +1032,6 @@ document_read_contents (YelpDocument *document,
             g_free (index_title);
         g_free (txt);
         g_string_append (ret, "</div></body></html>");
-        g_mutex_unlock (document->priv->mutex);
 
         hash_replace (document->priv->contents, page_id, g_string_free (ret, FALSE));
         str = hash_lookup (document->priv->contents, page_id);
@@ -1438,7 +1437,6 @@ request_idle_error (Request *request)
 	callback = request->callback;
 	user_data = request->user_data;
 	error = request->error;
-	request->error = NULL;
 	priv->reqs_pending = g_slist_remove (priv->reqs_pending, request);
     }
 
@@ -1451,6 +1449,7 @@ request_idle_error (Request *request)
 		  user_data,
 		  error);
 
+    g_clear_error (&request->error);
     g_object_unref (document);
     return FALSE;
 }
